@@ -95,7 +95,10 @@ class DocumentPrivate
         // private methods
         QString pagesSizeString() const;
         QString localizedSize(const QSizeF &size) const;
-        void cleanupPixmapMemory( qulonglong bytesOffset = 0 );
+        qulonglong calculateMemoryToFree();
+        void cleanupPixmapMemory();
+        void cleanupPixmapMemory( qulonglong memoryToFree );
+        AllocatedPixmap * searchLowestPriorityUnloadablePixmap( bool thenRemoveIt = false );
         void calculateMaxTextPages();
         qulonglong getTotalMemory();
         qulonglong getFreeMemory( qulonglong *freeSwap = 0 );
@@ -186,7 +189,7 @@ class DocumentPrivate
         QLinkedList< PixmapRequest * > m_pixmapRequestsStack;
         QLinkedList< PixmapRequest * > m_executingPixmapRequests;
         QMutex m_pixmapRequestsMutex;
-        QLinkedList< AllocatedPixmap * > m_allocatedPixmapsFifo;
+        QLinkedList< AllocatedPixmap * > m_allocatedPixmaps;
         qulonglong m_allocatedPixmapsTotalMemory;
         QList< int > m_allocatedTextPagesFifo;
         int m_maxAllocatedTextPages;
